teatime.reporting package
=========================

Submodules
----------

teatime.reporting.issue module
------------------------------

.. automodule:: teatime.reporting.issue
   :members:
   :undoc-members:
   :show-inheritance:

teatime.reporting.report module
-------------------------------

.. automodule:: teatime.reporting.report
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: teatime.reporting
   :members:
   :undoc-members:
   :show-inheritance:
